@@ -2,24 +2,19 @@
  * This is the Qt Designer plugin that collects all the Python plugins it can
  * find as a widget collection to Designer.
  *
- * Copyright (c) 2012 Riverbank Computing Limited <info@riverbankcomputing.com>
+ * Copyright (c) 2015 Riverbank Computing Limited <info@riverbankcomputing.com>
  * 
- * This file is part of PyQt.
+ * This file is part of PyQt4.
  * 
- * This file may be used under the terms of the GNU General Public
- * License versions 2.0 or 3.0 as published by the Free Software
- * Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
- * included in the packaging of this file.  Alternatively you may (at
- * your option) use any later version of the GNU General Public
- * License if such license has been publicly approved by Riverbank
- * Computing Limited (or its successors, if any) and the KDE Free Qt
- * Foundation. In addition, as a special exception, Riverbank gives you
- * certain additional rights. These rights are described in the Riverbank
- * GPL Exception version 1.1, which can be found in the file
- * GPL_EXCEPTION.txt in this package.
+ * This file may be used under the terms of the GNU General Public License
+ * version 3.0 as published by the Free Software Foundation and appearing in
+ * the file LICENSE included in the packaging of this file.  Please review the
+ * following information to ensure the GNU General Public License version 3.0
+ * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
  * 
- * If you are unsure which license is appropriate for your use, please
- * contact the sales department at sales@riverbankcomputing.com.
+ * If you do not wish to use this file under the terms of the GPL version 3.0
+ * then you may purchase a commercial license.  For more information contact
+ * info@riverbankcomputing.com.
  * 
  * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
  * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -36,7 +31,6 @@
 #include <QDesignerCustomWidgetInterface>
 #include <QDir>
 #include <QLibrary>
-#include <QLibraryInfo>
 #include <QStringList>
 #include <QVector>
 
@@ -218,7 +212,7 @@ PyCustomWidgets::PyCustomWidgets(QObject *parent) : QObject(parent)
                 dir.length() * sizeof (Py_UNICODE));
 #endif
 #else
-        PyObject *dobj = PyString_FromString(dir.toAscii().constData());
+        PyObject *dobj = PyString_FromString(dir.toLatin1().constData());
 
         if (!dobj)
         {
@@ -240,7 +234,7 @@ PyCustomWidgets::PyCustomWidgets(QObject *parent) : QObject(parent)
         // Import each plugin.
         for (int plug = 0; plug < plugins.size(); ++plug)
         {
-            PyObject *plug_mod = PyImport_ImportModule(plugins.at(plug).toAscii().data());
+            PyObject *plug_mod = PyImport_ImportModule(plugins.at(plug).toLatin1().data());
 
             if (!plug_mod)
             {
@@ -355,5 +349,7 @@ PyObject *PyCustomWidgets::getModuleAttr(const char *module, const char *attr)
 }
 
 
+#if QT_VERSION < 0x050000
 // Register the plugin.
 Q_EXPORT_PLUGIN2(MODULE_NAME, PyCustomWidgets)
+#endif
