@@ -43,7 +43,7 @@
 import os
 import sys
 
-from PyQt4 import QtCore, QtGui, QtHelp, QtXml
+from PyQt4 import QtCore, QtGui, QtXml
 
 from colors import Colors
 from demoitemanimation import DemoItemAnimation
@@ -96,6 +96,9 @@ class MenuManager(QtCore.QObject):
         return cls.pInstance
 
     def getResource(self, name):
+        if self.helpEngine is None:
+            return QtCore.QByteArray()
+
         ba = self.helpEngine.fileData(QtCore.QUrl(name))
 
         if ba.isEmpty():
@@ -117,6 +120,13 @@ class MenuManager(QtCore.QObject):
             sys.exit(-1)
 
     def initHelpEngine(self):
+        # Qt5's QtHelp crashes on exit because of an apparent bug in the tidy
+        # up of (non-existent) database connections in QtSql.
+        if QtCore.qVersion().startswith('5'):
+            return
+
+        from PyQt4 import QtHelp
+
         self.helpRootUrl = 'qthelp://com.trolltech.qt.%d%d%d/qdoc/' % (QtCore.QT_VERSION >> 16, (QtCore.QT_VERSION >> 8) & 0xff, QtCore.QT_VERSION & 0xff)
 
         # Store help collection file in cache dir of assistant.
@@ -426,6 +436,7 @@ class MenuManager(QtCore.QObject):
             return
 
         self.declarativeEngine = QtDeclarative.QDeclarativeEngine(self)
+        self.declarativeEngine.quit.connect(self.quitQML)
 
         component = QtDeclarative.QDeclarativeComponent(self.declarativeEngine,
                 QtCore.QUrl('qrc:/qml/qmlShell.qml'), self)
@@ -446,6 +457,10 @@ class MenuManager(QtCore.QObject):
         else:
             Colors.debug("Error initializing QML subsystem, Declarative examples will not work")
 
+    def quitQML(self):
+        if self.qmlRoot is not None:
+            self.qmlRoot.setProperty('show', False)
+
     def readInfoAboutExample(self, example):
         name = str(example.attribute('name'))
         if name in self.info:
