@@ -49,11 +49,31 @@ sip.setapi('QVariant', 2)
 from PyQt4 import QtCore, QtGui
 
 
+SUBJECT, SENDER, DATE = range(3)
+
+# Work around the fact that QSortFilterProxyModel always filters datetime
+# values in QtCore.Qt.ISODate format, but the tree views display using
+# QtCore.Qt.DefaultLocaleShortDate format.
+class SortFilterProxyModel(QtGui.QSortFilterProxyModel):
+    def filterAcceptsRow(self, sourceRow, sourceParent):
+        # Do we filter for the date column?
+        if self.filterKeyColumn() == DATE:
+            # Fetch datetime value.
+            index = self.sourceModel().index(sourceRow, DATE, sourceParent)
+            data = self.sourceModel().data(index)
+
+            # Return, if regExp match in displayed format.
+            return (self.filterRegExp().indexIn(data.toString(QtCore.Qt.DefaultLocaleShortDate)) >= 0)
+
+        # Not our business.
+        return super(SortFilterProxyModel, self).filterAcceptsRow(sourceRow, sourceParent)
+
+
 class Window(QtGui.QWidget):
     def __init__(self):
         super(Window, self).__init__()
 
-        self.proxyModel = QtGui.QSortFilterProxyModel()
+        self.proxyModel = SortFilterProxyModel()
         self.proxyModel.setDynamicSortFilter(True)
 
         self.sourceGroupBox = QtGui.QGroupBox("Original Model")
@@ -123,8 +143,8 @@ class Window(QtGui.QWidget):
         self.setWindowTitle("Basic Sort/Filter Model")
         self.resize(500, 450)
 
-        self.proxyView.sortByColumn(1, QtCore.Qt.AscendingOrder)
-        self.filterColumnComboBox.setCurrentIndex(1)
+        self.proxyView.sortByColumn(SENDER, QtCore.Qt.AscendingOrder)
+        self.filterColumnComboBox.setCurrentIndex(SENDER)
 
         self.filterPatternLineEdit.setText("Andy|Grace")
         self.filterCaseSensitivityCheckBox.setChecked(True)
@@ -161,17 +181,17 @@ class Window(QtGui.QWidget):
 
 def addMail(model, subject, sender, date):
     model.insertRow(0)
-    model.setData(model.index(0, 0), subject)
-    model.setData(model.index(0, 1), sender)
-    model.setData(model.index(0, 2), date)
+    model.setData(model.index(0, SUBJECT), subject)
+    model.setData(model.index(0, SENDER), sender)
+    model.setData(model.index(0, DATE), date)
 
 
 def createMailModel(parent):
     model = QtGui.QStandardItemModel(0, 3, parent)
 
-    model.setHeaderData(0, QtCore.Qt.Horizontal, "Subject")
-    model.setHeaderData(1, QtCore.Qt.Horizontal, "Sender")
-    model.setHeaderData(2, QtCore.Qt.Horizontal, "Date")
+    model.setHeaderData(SUBJECT, QtCore.Qt.Horizontal, "Subject")
+    model.setHeaderData(SENDER, QtCore.Qt.Horizontal, "Sender")
+    model.setHeaderData(DATE, QtCore.Qt.Horizontal, "Date")
 
     addMail(model, "Happy New Year!", "Grace K. <grace@software-inc.com>",
             QtCore.QDateTime(QtCore.QDate(2006, 12, 31), QtCore.QTime(17, 3)))
