@@ -1,4 +1,5 @@
 /**********************************************************************
+** Copyright (C) 2014 Riverbank Computing Limited
 ** Copyright (C) 2002-2007 Detlev Offenbach <detlev@die-offenbachs.de>
 **
 ** This is a modified version of lupdate. The original is part of Qt-Linguist.
@@ -64,6 +65,11 @@ enum { Tok_Eof, Tok_class, Tok_return, Tok_tr,
        Tok_LeftParen, Tok_RightParen,
        Tok_Comma, Tok_None, Tok_Integer};
 
+// The names of function aliases passed on the command line.
+static const char *tr_function;
+static const char *trUtf8_function;
+static const char *translate_function;
+
 /*
   The tokenizer maintains the following global variables. The names
   should be self-explanatory.
@@ -91,40 +97,74 @@ static FILE *yyInFile;
 // the string to read from and current position in the string (otherwise)
 static QString yyInStr;
 static int yyInPos;
-static int buf;
+// - 'rawbuf' is used to hold bytes before universal newline translation.
+// - 'buf' is its higher-level counterpart, where every end-of-line appears as
+//   a single '\n' character, regardless of the end-of-line style used in input
+//   files.
+static int buf, rawbuf;
 
 static int (*getChar)();
 static int (*peekChar)();
 
 static bool yyParsingUtf8;
 
+static int getTranslatedCharFromFile()
+{
+    int c;
+
+    if ( rawbuf < 0 )           // Empty raw buffer?
+        c = getc( yyInFile );
+    else {
+        c = rawbuf;
+        rawbuf = -1;            // Declare the raw buffer empty.
+    }
+
+    // Universal newline translation, similar to what Python does
+    if ( c == '\r' ) {
+        c = getc( yyInFile ); // Last byte of a \r\n sequence?
+        if ( c != '\n')
+            {
+                rawbuf = c; // No, put it in 'rawbuf' for later processing.
+                // Logical character that will be seen by higher-level functions
+                c = '\n';
+            }
+        // In all cases, c == '\n' here.
+    }
+
+    return c;
+}
+
 static int getCharFromFile()
 {
     int c;
 
-    if ( buf < 0 )
-        c = getc( yyInFile );
-    else {
+    if ( buf < 0 ) {            // Empty buffer?
+        c = getTranslatedCharFromFile();
+    } else {
         c = buf;
-        buf = -1;
+        buf = -1;               // Declare the buffer empty.
     }
-    if ( c == '\n' )
-        yyCurLineNo++;
+
+    if ( c == '\n' )            // This is after universal newline translation
+        yyCurLineNo++;          // (i.e., a "logical" newline character).
+
     return c;
 }
 
 static int peekCharFromFile()
 {
-    int c = getc( yyInFile );
-    buf = c;
-    return c;
+    // Read a character, possibly performing universal newline translation,
+    // and put it in 'buf' so that the next call to getCharFromFile() finds it
+    // already available.
+    buf = getCharFromFile();
+    return buf;
 }
 
 static void startTokenizer( const char *fileName, int (*getCharFunc)(),
                             int (*peekCharFunc)(), QTextCodec *codecForTr, QTextCodec *codecForSource )
 {
     yyInPos = 0;
-    buf = -1;
+    buf = rawbuf = -1;
     getChar = getCharFunc;
     peekChar = peekCharFunc;
 
@@ -165,6 +205,16 @@ static int getToken()
             } while ( isalnum(yyCh) || yyCh == '_' );
             yyIdent[yyIdentLen] = '\0';
 
+            // Check for names passed on the command line.
+            if (tr_function && strcmp(yyIdent, tr_function) == 0)
+                return Tok_tr;
+
+            if (trUtf8_function && strcmp(yyIdent, trUtf8_function) == 0)
+                return Tok_trUtf8;
+
+            if (translate_function && strcmp(yyIdent, translate_function) == 0)
+                return Tok_translate;
+
             bool might_be_str = false;
 
             switch ( yyIdent[0] ) {
@@ -239,6 +289,9 @@ static int getToken()
                     } else if ( strcmp(yyIdent + 1, "_trUtf8") == 0 ) {
                         yyParsingUtf8 = true;
                         return Tok_trUtf8;
+                    } else if ( qstrcmp(yyIdent + 1, "translate") == 0 ) {
+                        yyParsingUtf8 = false;
+                        return Tok_translate;
                     }
                     break;
             }
@@ -309,18 +362,18 @@ static int getToken()
                             if ( yyCh == 'x' ) {
                                 QByteArray hex = "0";
 
-                            yyCh = getChar();
-                            while ( isxdigit(yyCh) ) {
-                                hex += (char) yyCh;
                                 yyCh = getChar();
-                            }
+                                while ( isxdigit(yyCh) ) {
+                                    hex += (char) yyCh;
+                                    yyCh = getChar();
+                                }
 #if defined(_MSC_VER) && _MSC_VER >= 1400
-                            sscanf_s( hex, "%x", &n );
+                                sscanf_s( hex, "%x", &n );
 #else
-                            sscanf( hex, "%x", &n );
+                                sscanf( hex, "%x", &n );
 #endif
-                            if ( yyStringLen < sizeof(yyString) - 1 )
-                                yyString[yyStringLen++] = (char) n;
+                                if ( yyStringLen < sizeof(yyString) - 1 )
+                                    yyString[yyStringLen++] = (char) n;
                             } else if ( yyCh >= '0' && yyCh < '8' ) {
                                 QByteArray oct = "";
                                 int n = 0;
@@ -337,6 +390,8 @@ static int getToken()
     #endif
                                 if ( yyStringLen < sizeof(yyString) - 1 )
                                     yyString[yyStringLen++] = (char) n;
+                            } else if ( yyCh == '\n' ) {
+                                yyCh = getChar();
                             } else {
                                 const char *p = strchr( tab, yyCh );
                                 if ( yyStringLen < sizeof(yyString) - 1 )
@@ -730,16 +785,22 @@ static void parse( MetaTranslator *tor, const char *initialContext,
             (const char *) yyFileName );
 }
 
-void fetchtr_py( const char *fileName, MetaTranslator *tor,
-                  const char *defaultContext, bool mustExist, const QByteArray &codecForSource )
+void fetchtr_py(const char *fileName, MetaTranslator *tor,
+        const char *defaultContext, bool mustExist,
+        const QByteArray &codecForSource, const char *tr_func,
+        const char *trUtf8_func, const char *translate_func)
 {
+    tr_function = tr_func;
+    trUtf8_function = trUtf8_func;
+    translate_function = translate_func;
+
 #if defined(_MSC_VER) && _MSC_VER >= 1400
     if (fopen_s(&yyInFile, fileName, "r")) {
         if ( mustExist ) {
             char buf[100];
             strerror_s(buf, sizeof(buf), errno);
             fprintf( stderr,
-                     "pylupdate4 error: Cannot open Python source file '%s': %s\n",
+                     "pylupdate5 error: Cannot open Python source file '%s': %s\n",
                      fileName, buf );
         }
 #else
@@ -747,7 +808,7 @@ void fetchtr_py( const char *fileName, MetaTranslator *tor,
     if ( yyInFile == 0 ) {
         if ( mustExist )
             fprintf( stderr,
-                     "pylupdate4 error: Cannot open Python source file '%s': %s\n",
+                     "pylupdate5 error: Cannot open Python source file '%s': %s\n",
                      fileName, strerror(errno) );
 #endif
         return;
@@ -870,10 +931,10 @@ void fetchtr_ui( const char *fileName, MetaTranslator *tor,
 #if defined(_MSC_VER) && _MSC_VER >= 1400
             char buf[100];
             strerror_s(buf, sizeof(buf), errno);
-            fprintf( stderr, "pylupdate4 error: cannot open UI file '%s': %s\n",
+            fprintf( stderr, "pylupdate5 error: cannot open UI file '%s': %s\n",
                      fileName, buf );
 #else
-            fprintf( stderr, "pylupdate4 error: cannot open UI file '%s': %s\n",
+            fprintf( stderr, "pylupdate5 error: cannot open UI file '%s': %s\n",
                      fileName, strerror(errno) );
 #endif
         }
