@@ -47,8 +47,10 @@
 #include <string.h>
 
 // defined in fetchtr.cpp
-extern void fetchtr_py( const char *fileName, MetaTranslator *tor,
-                         const char *defaultContext, bool mustExist, const QByteArray &codecForSource );
+extern void fetchtr_py(const char *fileName, MetaTranslator *tor,
+        const char *defaultContext, bool mustExist,
+        const QByteArray &codecForSource, const char *tr_func,
+        const char *trUtf8_func, const char *translate_func);
 extern void fetchtr_ui( const char *fileName, MetaTranslator *tor,
                          const char *defaultContext, bool mustExist );
 
@@ -67,12 +69,18 @@ static void printUsage()
              "    pylupdate4 [options] source-files -ts ts-files\n"
              "Options:\n"
              "    -help  Display this information and exit\n"
-             "    -noobsolete\n"
-             "           Drop all obsolete strings\n"
+             "    -version\n"
+             "           Display the version of pylupdate4 and exit\n"
              "    -verbose\n"
              "           Explain what is being done\n"
-             "    -version\n"
-             "           Display the version of pylupdate4 and exit\n" );
+             "    -noobsolete\n"
+             "           Drop all obsolete strings\n"
+             "    -tr-function name\n"
+             "           name() may be used instead of tr()\n"
+             "    -trUtf8-function name\n"
+             "           name() may be used instead of trUtf8()\n"
+             "    -translate-function name\n"
+             "           name() may be used instead of translate()\n");
 }
 
 static void updateTsFiles( const MetaTranslator& fetchedTor,
@@ -125,6 +133,9 @@ int main( int argc, char **argv )
     int numFiles = 0;
     bool standardSyntax = true;
     bool metTsFlag = false;
+    const char *tr_func = 0;
+    const char *trUtf8_func = 0;
+    const char *translate_func = 0;
 
     int i;
 
@@ -149,6 +160,36 @@ int main( int argc, char **argv )
         } else if ( qstrcmp(argv[i], "-ts") == 0 ) {
             metTsFlag = true;
             continue;
+        } else if ( qstrcmp(argv[i], "-tr-function") == 0 ) {
+            if (!argv[++i])
+            {
+                fprintf(stderr,
+                        "pylupdate5 error: missing -tr-function name\n");
+                return 2;
+            }
+
+            tr_func = argv[i];
+            continue;
+        } else if ( qstrcmp(argv[i], "-trUtf8-function") == 0 ) {
+            if (!argv[++i])
+            {
+                fprintf(stderr,
+                        "pylupdate5 error: missing -trUtf8-function name\n");
+                return 2;
+            }
+
+            trUtf8_func = argv[i];
+            continue;
+        } else if ( qstrcmp(argv[i], "-translate-function") == 0 ) {
+            if (!argv[++i])
+            {
+                fprintf(stderr,
+                        "pylupdate5 error: missing -translate-function name\n");
+                return 2;
+            }
+
+            translate_func = argv[i];
+            continue;
         }
 
         numFiles++;
@@ -194,10 +235,15 @@ int main( int argc, char **argv )
 
                 for ( t = toks.begin(); t != toks.end(); ++t ) {
                     if ( it.key() == "SOURCES" ) {
-                        fetchtr_py( (*t).toLatin1(), &fetchedTor, defaultContext.toLatin1(), true, codecForSource );
+                        QString abs = QDir::current().absoluteFilePath(*t);
+                        fetchtr_py(abs.toLatin1(), &fetchedTor,
+                                defaultContext.toLatin1(), true,
+                                codecForSource, tr_func, trUtf8_func,
+                                translate_func);
                         metSomething = true;
                     } else if ( it.key() == "TRANSLATIONS" ) {
-                        tsFileNames.append( *t );
+                        QString abs = QDir::current().absoluteFilePath(*t);
+                        tsFileNames.append(abs);
                         metSomething = true;
                     } else if ( it.key() == "CODEC" ||
                                 it.key() == "DEFAULTCODEC" ||
@@ -207,8 +253,10 @@ int main( int argc, char **argv )
                     } else if ( it.key() == "CODECFORSRC" ) {
                         codecForSource = (*t).toLatin1();
                     } else if ( it.key() == "FORMS" ) {
-                fetchtr_ui( (*t).toLatin1(), &fetchedTor, defaultContext.toLatin1(), true);
-            }
+                        QString abs = QDir::current().absoluteFilePath(*t);
+                        fetchtr_ui(abs.toLatin1(), &fetchedTor,
+                                defaultContext.toLatin1(), true);
+                    }
                 }
             }
 
@@ -245,7 +293,9 @@ int main( int argc, char **argv )
             } else {
                 QFileInfo fi(argv[i]);
         if ( fi.suffix() == "py" || fi.suffix() == "pyw" ) {
-            fetchtr_py( fi.fileName().toLatin1(), &fetchedTor, defaultContext.toLatin1(), true, codecForSource );
+            fetchtr_py(fi.fileName().toLatin1(), &fetchedTor,
+                    defaultContext.toLatin1(), true, codecForSource, tr_func,
+                    trUtf8_func, translate_func);
         } else {
             fetchtr_ui( fi.fileName().toLatin1(), &fetchedTor, defaultContext.toLatin1(), true);
         }
