@@ -1,23 +1,18 @@
 // This is the implementation of the Chimera class.
 //
-// Copyright (c) 2012 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2015 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
-// This file is part of PyQt.
+// This file is part of PyQt4.
 // 
-// This file may be used under the terms of the GNU General Public
-// License versions 2.0 or 3.0 as published by the Free Software
-// Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-// included in the packaging of this file.  Alternatively you may (at
-// your option) use any later version of the GNU General Public
-// License if such license has been publicly approved by Riverbank
-// Computing Limited (or its successors, if any) and the KDE Free Qt
-// Foundation. In addition, as a special exception, Riverbank gives you
-// certain additional rights. These rights are described in the Riverbank
-// GPL Exception version 1.1, which can be found in the file
-// GPL_EXCEPTION.txt in this package.
+// This file may be used under the terms of the GNU General Public License
+// version 3.0 as published by the Free Software Foundation and appearing in
+// the file LICENSE included in the packaging of this file.  Please review the
+// following information to ensure the GNU General Public License version 3.0
+// requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 // 
-// If you are unsure which license is appropriate for your use, please
-// contact the sales department at sales@riverbankcomputing.com.
+// If you do not wish to use this file under the terms of the GPL version 3.0
+// then you may purchase a commercial license.  For more information contact
+// info@riverbankcomputing.com.
 // 
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -52,10 +47,15 @@ Chimera::ToQVariantConvertors Chimera::_registered_QVariant_convertors;
 // The registered PyObject to QVariant data convertors.
 Chimera::ToQVariantDataConvertors Chimera::_registered_QVariant_data_convertors;
 
+#if QT_VERSION >= 0x050000
+const int UnknownType = QMetaType::UnknownType;
+#else
+const int UnknownType = QMetaType::Void;
+#endif
 
 // Construct an invalid type.
 Chimera::Chimera()
-    : _type(0), _py_type(0), _metatype(QMetaType::Void), _inexact(false),
+    : _type(0), _py_type(0), _metatype(UnknownType), _inexact(false),
       _is_flag(false)
 {
 }
@@ -531,7 +531,7 @@ bool Chimera::parse_py_type(PyTypeObject *type_obj)
     }
 
     // Fallback to using a PyQt_PyObject.
-    if (_metatype == QMetaType::Void)
+    if (_metatype == UnknownType)
         _metatype = PyQt_PyObject::metatype;
 
     // If there is no name so far then use the meta-type name.
@@ -549,7 +549,7 @@ bool Chimera::parse_py_type(PyTypeObject *type_obj)
 void Chimera::set_flag()
 {
     if (qpycore_is_pyqt4_class(_type))
-        _is_flag = ((pyqt4ClassTypeDef *)_type)->qt4_flags & 0x01;
+        _is_flag = ((pyqt4ClassTypeDef *)_type)->flags & 0x01;
 }
 
 
@@ -688,7 +688,7 @@ bool Chimera::parse_cpp_type(const QByteArray &type)
     _metatype = QMetaType::type(resolved.constData());
 
     // If not then use the PyQt_PyObject wrapper.
-    if (_metatype == QMetaType::Void)
+    if (_metatype == UnknownType)
         _metatype = PyQt_PyObject::metatype;
 
     // See if the type (without a pointer) is known to SIP.
@@ -1088,7 +1088,7 @@ bool Chimera::fromPyObject(PyObject *py, QVariant *var, bool strict) const
                     PyErr_Clear();
 
                     *var = keep_as_pyobject(py);
-                    metatype_used = QMetaType::Void;
+                    metatype_used = UnknownType;
                 }
                 else
                 {
@@ -1198,7 +1198,7 @@ bool Chimera::fromPyObject(PyObject *py, QVariant *var, bool strict) const
             if (to_QVariantList(py, ql))
             {
                 *var = QVariant(ql);
-                metatype_used = QMetaType::Void;
+                metatype_used = UnknownType;
             }
             else
             {
@@ -1215,7 +1215,7 @@ bool Chimera::fromPyObject(PyObject *py, QVariant *var, bool strict) const
             if (to_QVariantMap(py, qm))
             {
                 *var = QVariant(qm);
-                metatype_used = QMetaType::Void;
+                metatype_used = UnknownType;
             }
             else if (strict)
             {
@@ -1227,7 +1227,7 @@ bool Chimera::fromPyObject(PyObject *py, QVariant *var, bool strict) const
                 PyErr_Clear();
 
                 *var = keep_as_pyobject(py);
-                metatype_used = QMetaType::Void;
+                metatype_used = UnknownType;
             }
 
             break;
@@ -1241,7 +1241,7 @@ bool Chimera::fromPyObject(PyObject *py, QVariant *var, bool strict) const
             if (to_QVariantHash(py, qh))
             {
                 *var = QVariant(qh);
-                metatype_used = QMetaType::Void;
+                metatype_used = UnknownType;
             }
             else
             {
@@ -1301,7 +1301,7 @@ bool Chimera::fromPyObject(PyObject *py, QVariant *var, bool strict) const
     {
         *var = QVariant(*reinterpret_cast<QVariant *>(variant_data));
     }
-    else if (metatype_used != QMetaType::Void)
+    else if (metatype_used != UnknownType)
     {
         *var = QVariant(metatype_used, variant_data);
     }
